#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hspec
version:              1.2.0.4
visibility:           public
id:                   tasty-hspec-1.2.0.4-7sZaaftbdh33asOFvuR7Kc
key:                  tasty-hspec-1.2.0.4-7sZaaftbdh33asOFvuR7Kc
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  bf0a82e7d0a4582986a7cec6a6ab0df9
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-hspec-1.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.4-7sZaaftbdh33asOFvuR7Kc
depends:
    QuickCheck-2.15.0.1-F4KSbaKYMsC7ZlbvInQnfK base-4.18.2.1
    hspec-2.11.6-CVn2jPWk635KSZ9qZsmTv4
    hspec-api-2.11.6-HPfL44eSe8DCScqWeuw7Og
    hspec-core-2.11.6-5leMO9JxG4e60sEsEgKGH0
    tasty-1.5.3-53ADb4g03a0EJGveocITRv
    tasty-quickcheck-0.11.1-3rLrJrEk2uMAqIN03nD1J6
    tasty-smallcheck-0.8.2-31UQvPoX7wkGx4oclYzcJD

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

